import React from 'react';
import { CellProps, ContainerProps, HorizontalAlignment, Overflow, TableOptions } from './types.js';
export declare function formatTextWithMargins({ horizontalAlignment, overflow, padding, value, width, }: {
    overflow: Overflow;
    value: unknown;
    width: number;
    padding: number;
    horizontalAlignment: HorizontalAlignment;
}): {
    text: string;
    marginLeft: number;
    marginRight: number;
};
export declare function Table<T extends Record<string, unknown>>(props: TableOptions<T>): React.JSX.Element;
/**
 * Renders the header of a table.
 */
export declare function Header(props: React.PropsWithChildren): React.JSX.Element;
/**
 * Renders a cell in the table.
 */
export declare function Cell(props: CellProps): React.JSX.Element;
/**
 * Renders the scaffold of the table.
 */
export declare function Skeleton(props: React.PropsWithChildren & {
    readonly height?: number;
}): React.JSX.Element;
/**
 * Renders a table with the given data.
 * @param options see {@link TableOptions}
 */
export declare function printTable<T extends Record<string, unknown>>(options: TableOptions<T>): void;
export declare function printTables<T extends Record<string, unknown>[]>(tables: {
    [P in keyof T]: TableOptions<T[P]>;
}, options?: Omit<ContainerProps, 'children'>): void;
